@@ -11,27 +11,37 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Callable, Dict, List, Mapping, Optional, Sequence, TYPE_CHECKING, Union
+from typing import Any, Callable, Dict, List, Mapping, Optional, Sequence, Union
 
 import torch
 import torch.nn.functional as F
-import torchmetrics
-from pytorch_lightning.utilities import rank_zero_deprecation, rank_zero_warn
+from pytorch_lightning.utilities import rank_zero_warn
+from torchmetrics import Accuracy, Metric
 
 from flash.core.adapter import AdapterTask
-from flash.core.data.io.classification_input import ClassificationState
 from flash.core.data.io.input import DataKeys
 from flash.core.data.io.output import Output
 from flash.core.model import Task
-from flash.core.utilities.imports import _FIFTYONE_AVAILABLE, lazy_import, requires
+from flash.core.registry import FlashRegistry
+from flash.core.utilities.imports import _FIFTYONE_AVAILABLE, _TM_GREATER_EQUAL_0_7_0, lazy_import, requires
+from flash.core.utilities.providers import _FIFTYONE
 
-Classification, Classifications = None, None
 if _FIFTYONE_AVAILABLE:
     fol = lazy_import("fiftyone.core.labels")
-    if TYPE_CHECKING:
-        from fiftyone.core.labels import Classification, Classifications
+    Classification = "fiftyone.core.labels.Classification"
+    Classifications = "fiftyone.core.labels.Classifications"
 else:
     fol = None
+    Classification = None
+    Classifications = None
+
+if _TM_GREATER_EQUAL_0_7_0:
+    from torchmetrics import F1Score
+else:
+    from torchmetrics import F1 as F1Score
+
+
+CLASSIFICATION_OUTPUTS = FlashRegistry("outputs")
 
 
 def binary_cross_entropy_with_logits(x: torch.Tensor, y: torch.Tensor) -> torch.Tensor:
@@ -40,15 +50,20 @@ def binary_cross_entropy_with_logits(x: torch.Tensor, y: torch.Tensor) -> torch.
 
 
 class ClassificationMixin:
-    @staticmethod
     def _build(
+        self,
         num_classes: Optional[int] = None,
+        labels: Optional[List[str]] = None,
         loss_fn: Optional[Callable] = None,
-        metrics: Union[torchmetrics.Metric, Mapping, Sequence, None] = None,
+        metrics: Union[Metric, Mapping, Sequence, None] = None,
         multi_label: bool = False,
     ):
+        self.num_classes = num_classes
+        self.multi_label = multi_label
+        self.labels = labels
+
         if metrics is None:
-            metrics = torchmetrics.F1(num_classes) if (multi_label and num_classes) else torchmetrics.Accuracy()
+            metrics = F1Score(num_classes) if (multi_label and num_classes) else Accuracy()
 
         if loss_fn is None:
             loss_fn = binary_cross_entropy_with_logits if multi_label else F.cross_entropy
@@ -56,53 +71,57 @@ class ClassificationMixin:
         return metrics, loss_fn
 
     def to_metrics_format(self, x: torch.Tensor) -> torch.Tensor:
-        if getattr(self.hparams, "multi_label", False):
+        if getattr(self, "multi_label", False):
             return torch.sigmoid(x)
         return torch.softmax(x, dim=1)
 
 
-class ClassificationTask(Task, ClassificationMixin):
+class ClassificationTask(ClassificationMixin, Task):
+
+    outputs: FlashRegistry = Task.outputs + CLASSIFICATION_OUTPUTS
+
     def __init__(
         self,
         *args,
         num_classes: Optional[int] = None,
         loss_fn: Optional[Callable] = None,
-        metrics: Union[torchmetrics.Metric, Mapping, Sequence, None] = None,
+        metrics: Union[Metric, Mapping, Sequence, None] = None,
         multi_label: bool = False,
-        output: Optional[Union[Output, Mapping[str, Output]]] = None,
+        labels: Optional[List[str]] = None,
         **kwargs,
     ) -> None:
 
-        metrics, loss_fn = ClassificationMixin._build(num_classes, loss_fn, metrics, multi_label)
+        metrics, loss_fn = self._build(num_classes, labels, loss_fn, metrics, multi_label)
 
         super().__init__(
             *args,
             loss_fn=loss_fn,
             metrics=metrics,
-            output=output or ClassesOutput(multi_label=multi_label),
             **kwargs,
         )
 
 
-class ClassificationAdapterTask(AdapterTask, ClassificationMixin):
+class ClassificationAdapterTask(ClassificationMixin, AdapterTask):
+
+    outputs: FlashRegistry = Task.outputs + CLASSIFICATION_OUTPUTS
+
     def __init__(
         self,
         *args,
         num_classes: Optional[int] = None,
         loss_fn: Optional[Callable] = None,
-        metrics: Union[torchmetrics.Metric, Mapping, Sequence, None] = None,
+        metrics: Union[Metric, Mapping, Sequence, None] = None,
         multi_label: bool = False,
-        output: Optional[Union[Output, Mapping[str, Output]]] = None,
+        labels: Optional[List[str]] = None,
         **kwargs,
     ) -> None:
 
-        metrics, loss_fn = ClassificationMixin._build(num_classes, loss_fn, metrics, multi_label)
+        metrics, loss_fn = self._build(num_classes, labels, loss_fn, metrics, multi_label)
 
         super().__init__(
             *args,
             loss_fn=loss_fn,
             metrics=metrics,
-            output=output or ClassesOutput(multi_label=multi_label),
             **kwargs,
         )
 
@@ -119,11 +138,16 @@ class ClassificationOutput(Output):
 
         self._mutli_label = multi_label
 
+    @classmethod
+    def from_task(cls, task: Task, **kwargs) -> Output:
+        return cls(multi_label=getattr(task, "multi_label", False))
+
     @property
     def multi_label(self) -> bool:
         return self._mutli_label
 
 
+@CLASSIFICATION_OUTPUTS(name="preds")
 class PredsClassificationOutput(ClassificationOutput):
     """A :class:`~flash.core.classification.ClassificationOutput` which gets the
     :attr:`~flash.core.data.io.input.InputFormat.PREDS` from the sample.
@@ -137,6 +161,7 @@ class PredsClassificationOutput(ClassificationOutput):
         return sample
 
 
+@CLASSIFICATION_OUTPUTS(name="logits")
 class LogitsOutput(PredsClassificationOutput):
     """A :class:`.Output` which simply converts the model outputs (assumed to be logits) to a list."""
 
@@ -144,6 +169,7 @@ class LogitsOutput(PredsClassificationOutput):
         return super().transform(sample).tolist()
 
 
+@CLASSIFICATION_OUTPUTS(name="probabilities")
 class ProbabilitiesOutput(PredsClassificationOutput):
     """A :class:`.Output` which applies a softmax to the model outputs (assumed to be logits) and converts to a
     list."""
@@ -155,6 +181,7 @@ class ProbabilitiesOutput(PredsClassificationOutput):
         return torch.softmax(sample, -1).tolist()
 
 
+@CLASSIFICATION_OUTPUTS(name="classes")
 class ClassesOutput(PredsClassificationOutput):
     """A :class:`.Output` which applies an argmax to the model outputs (either logits or probabilities) and
     converts to a list.
@@ -181,13 +208,13 @@ class ClassesOutput(PredsClassificationOutput):
         return torch.argmax(sample, -1).tolist()
 
 
+@CLASSIFICATION_OUTPUTS(name="labels")
 class LabelsOutput(ClassesOutput):
     """A :class:`.Output` which converts the model outputs (either logits or probabilities) to the label of the
     argmax classification.
 
     Args:
-        labels: A list of labels, assumed to map the class index to the label for that class. If ``labels`` is not
-            provided, will attempt to get them from the :class:`.ClassificationState`.
+        labels: A list of labels, assumed to map the class index to the label for that class.
         multi_label: If true, treats outputs as multi label logits.
         threshold: The threshold to use for multi_label classification.
     """
@@ -196,35 +223,27 @@ class LabelsOutput(ClassesOutput):
         super().__init__(multi_label=multi_label, threshold=threshold)
         self._labels = labels
 
-        if labels is not None:
-            self.set_state(ClassificationState(labels))
+    @classmethod
+    def from_task(cls, task: Task, **kwargs) -> Output:
+        return cls(labels=getattr(task, "labels", None), multi_label=getattr(task, "multi_label", False))
 
     def transform(self, sample: Any) -> Union[int, List[int], str, List[str]]:
-        labels = None
-
-        if self._labels is not None:
-            labels = self._labels
-        else:
-            state = self.get_state(ClassificationState)
-            if state is not None:
-                labels = state.labels
-
         classes = super().transform(sample)
 
-        if labels is not None:
+        if self._labels is not None:
             if self.multi_label:
-                return [labels[cls] for cls in classes]
-            return labels[classes]
-        rank_zero_warn("No ClassificationState was found, this output will act as a Classes output.", UserWarning)
+                return [self._labels[cls] for cls in classes]
+            return self._labels[classes]
+        rank_zero_warn("No labels were provided, this output will act as a Classes output.", UserWarning)
         return classes
 
 
+@CLASSIFICATION_OUTPUTS(name="fiftyone", providers=_FIFTYONE)
 class FiftyOneLabelsOutput(ClassificationOutput):
     """A :class:`.Output` which converts the model outputs to FiftyOne classification format.
 
     Args:
-        labels: A list of labels, assumed to map the class index to the label for that class. If ``labels`` is not
-            provided, will attempt to get them from the :class:`.ClassificationState`.
+        labels: A list of labels, assumed to map the class index to the label for that class.
         multi_label: If true, treats outputs as multi label logits.
         threshold: A threshold to use to filter candidate labels. In the single label case, predictions below this
             threshold will be replaced with None
@@ -241,7 +260,7 @@ class FiftyOneLabelsOutput(ClassificationOutput):
         multi_label: bool = False,
         threshold: Optional[float] = None,
         store_logits: bool = False,
-        return_filepath: bool = False,
+        return_filepath: bool = True,
     ):
         if multi_label and threshold is None:
             threshold = 0.5
@@ -252,8 +271,9 @@ class FiftyOneLabelsOutput(ClassificationOutput):
         self.store_logits = store_logits
         self.return_filepath = return_filepath
 
-        if labels is not None:
-            self.set_state(ClassificationState(labels))
+    @classmethod
+    def from_task(cls, task: Task, **kwargs) -> Output:
+        return cls(labels=getattr(task, "labels", None), multi_label=getattr(task, "multi_label", False))
 
     def transform(
         self,
@@ -262,15 +282,6 @@ class FiftyOneLabelsOutput(ClassificationOutput):
         pred = sample[DataKeys.PREDS] if isinstance(sample, Dict) else sample
         pred = torch.tensor(pred)
 
-        labels = None
-
-        if self._labels is not None:
-            labels = self._labels
-        else:
-            state = self.get_state(ClassificationState)
-            if state is not None:
-                labels = state.labels
-
         logits = None
         if self.store_logits:
             logits = pred.tolist()
@@ -286,12 +297,12 @@ class FiftyOneLabelsOutput(ClassificationOutput):
             classes = torch.argmax(pred, -1).tolist()
             probabilities = torch.softmax(pred, -1).tolist()
 
-        if labels is not None:
+        if self._labels is not None:
             if self.multi_label:
                 classifications = []
                 for idx in classes:
                     fo_cls = fol.Classification(
-                        label=labels[idx],
+                        label=self._labels[idx],
                         confidence=probabilities[idx],
                     )
                     classifications.append(fo_cls)
@@ -305,12 +316,12 @@ class FiftyOneLabelsOutput(ClassificationOutput):
                     fo_predictions = None
                 else:
                     fo_predictions = fol.Classification(
-                        label=labels[classes],
+                        label=self._labels[classes],
                         confidence=confidence,
                         logits=logits,
                     )
         else:
-            rank_zero_warn("No ClassificationState was found, int targets will be used as label strings", UserWarning)
+            rank_zero_warn("No labels were provided, int targets will be used as label strings", UserWarning)
 
             if self.multi_label:
                 classifications = []
@@ -339,20 +350,3 @@ class FiftyOneLabelsOutput(ClassificationOutput):
             filepath = sample[DataKeys.METADATA]["filepath"]
             return {"filepath": filepath, "predictions": fo_predictions}
         return fo_predictions
-
-
-class Labels(LabelsOutput):
-    def __init__(self, labels: Optional[List[str]] = None, multi_label: bool = False, threshold: float = 0.5):
-        rank_zero_deprecation(
-            "`Labels` was deprecated in v0.6.0 and will be removed in v0.7.0." "Please use `LabelsOutput` instead."
-        )
-        super().__init__(labels=labels, multi_label=multi_label, threshold=threshold)
-
-
-class Probabilities(ProbabilitiesOutput):
-    def __init__(self, multi_label: bool = False):
-        rank_zero_deprecation(
-            "`Probabilities` was deprecated in v0.6.0 and will be removed in v0.7.0."
-            "Please use `ProbabilitiesOutput` instead."
-        )
-        super().__init__(multi_label=multi_label)
