@@ -11,10 +11,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, Optional, Union
 
 from torchmetrics import BLEUScore
 
+from flash.core.utilities.imports import _TM_GREATER_EQUAL_0_7_0
 from flash.core.utilities.types import LOSS_FN_TYPE, LR_SCHEDULER_TYPE, METRICS_TYPE, OPTIMIZER_TYPE
 from flash.text.seq2seq.core.model import Seq2SeqTask
 
@@ -26,19 +27,18 @@ class TranslationTask(Seq2SeqTask):
     You can change the backbone to any translation model from `HuggingFace/transformers
     <https://huggingface.co/models?filter=pytorch&pipeline_tag=translation>`__ using the ``backbone`` argument.
 
-    .. note:: When changing the backbone, make sure you pass in the same backbone to the :class:`~flash.Task` and the
-        :class:`~flash.core.data.data_module.DataModule` object! Since this is a Seq2Seq task, make sure you use a
-        Seq2Seq model.
-
     Args:
         backbone: backbone model to use for the task.
+        max_source_length: The maximum length to pad / truncate input sequences to.
+        max_target_length: The maximum length to pad / truncate target sequences to.
+        padding: The type of padding to apply. One of: "longest" or ``True``, "max_length", "do_not_pad" or
+            ``False``.
         loss_fn: Loss function for training.
         optimizer: Optimizer to use for training.
         lr_scheduler: The LR scheduler to use during training.
         metrics: Metrics to compute for training and evaluation. Defauls to calculating the BLEU metric.
             Changing this argument currently has no effect.
         learning_rate: Learning rate to use for training, defaults to `1e-5`
-        val_target_max_length: Maximum length of targets in validation. Defaults to `128`
         num_beams: Number of beams to use in validation when generating predictions. Defaults to `4`
         n_gram: Maximum n_grams to use in metric calculation. Defaults to `4`
         smooth: Apply smoothing in BLEU calculation. Defaults to `True`
@@ -49,12 +49,14 @@ class TranslationTask(Seq2SeqTask):
         self,
         backbone: str = "t5-small",
         tokenizer_kwargs: Optional[Dict[str, Any]] = None,
+        max_source_length: int = 128,
+        max_target_length: int = 128,
+        padding: Union[str, bool] = "max_length",
         loss_fn: LOSS_FN_TYPE = None,
         optimizer: OPTIMIZER_TYPE = "Adam",
         lr_scheduler: LR_SCHEDULER_TYPE = None,
         metrics: METRICS_TYPE = None,
-        learning_rate: float = 1e-5,
-        val_target_max_length: Optional[int] = 128,
+        learning_rate: Optional[float] = None,
         num_beams: Optional[int] = 4,
         n_gram: bool = 4,
         smooth: bool = True,
@@ -64,12 +66,14 @@ class TranslationTask(Seq2SeqTask):
         super().__init__(
             backbone=backbone,
             tokenizer_kwargs=tokenizer_kwargs,
+            max_source_length=max_source_length,
+            max_target_length=max_target_length,
+            padding=padding,
             loss_fn=loss_fn,
             optimizer=optimizer,
             lr_scheduler=lr_scheduler,
             metrics=metrics,
             learning_rate=learning_rate,
-            val_target_max_length=val_target_max_length,
             num_beams=num_beams,
             enable_ort=enable_ort,
         )
@@ -83,17 +87,15 @@ class TranslationTask(Seq2SeqTask):
         return "translation"
 
     def compute_metrics(self, generated_tokens, batch, prefix):
-        reference_corpus = self.tokenize_labels(batch["labels"])
+        reference_corpus = self.decode(batch["labels"])
         # wrap targets in list as score expects a list of potential references
         reference_corpus = [[reference] for reference in reference_corpus]
 
-        translate_corpus = self._output_transform.uncollate(generated_tokens)
+        translate_corpus = self.decode(generated_tokens)
         translate_corpus = [line for line in translate_corpus]
 
-        result = self.bleu(reference_corpus, translate_corpus)
+        if _TM_GREATER_EQUAL_0_7_0:
+            result = self.bleu(translate_corpus, reference_corpus)
+        else:
+            result = self.bleu(reference_corpus, translate_corpus)
         self.log(f"{prefix}_bleu_score", result, on_step=False, on_epoch=True, prog_bar=True)
-
-    @staticmethod
-    def _ci_benchmark_fn(history: List[Dict[str, Any]]):
-        """This function is used only for debugging usage with CI."""
-        assert history[-1]["val_bleu_score"] > 0.6, history[-1]["val_bleu_score"]
